fhirpack.transformation package — fhirpack 0.0.2b0 documentation

# fhirpack.transformation package

## Submodules

## fhirpack.transformation.base module

class fhirpack.transformation.base.BaseTransformerMixin

  Bases: `object`

  __dict__ = mappingproxy({'__module__': 'fhirpack.transformation.base', 'validate': <function BaseTransformerMixin.validate>, 'gatherSimplePaths': <function BaseTransformerMixin.gatherSimplePaths>, '_BaseTransformerMixin__gatherSimplePath': <function BaseTransformerMixin.__gatherSimplePath>, 'gatherReferences': <function BaseTransformerMixin.gatherReferences>, 'gatherText': <function BaseTransformerMixin.gatherText>, 'gatherKeys': <function BaseTransformerMixin.gatherKeys>, 'gatherValuesForKeys': <function BaseTransformerMixin.gatherValuesForKeys>, 'gatherDates': <function BaseTransformerMixin.gatherDates>, '__dict__': <attribute '__dict__' of 'BaseTransformerMixin' objects>, '__weakref__': <attribute '__weakref__' of 'BaseTransformerMixin' objects>, '__doc__': None, '__annotations__': {}})
  __doc__ = None
  __gatherSimplePath(data: dict, path: Union[str, list[str]])
  __module__ = 'fhirpack.transformation.base'
  __weakref__

    list of weak references to the object (if defined)

  gatherDates(recursive: bool = False, input: Optional[Union[list[str], list[fhirpy.lib.SyncFHIRReference], list[fhirpy.lib.SyncFHIRResource]]] = None, params: Optional[dict] = None)
  gatherKeys(params: Optional[dict] = None, input: Optional[Union[list[str], list[fhirpy.lib.SyncFHIRReference], list[fhirpy.lib.SyncFHIRResource]]] = None)
  gatherReferences(references: Optional[Union[list[str], list[fhirpy.lib.SyncFHIRReference], list[fhirpy.lib.SyncFHIRResource]]] = None, recursive: bool = False)
  gatherSimplePaths(paths: list[str], input: Optional[Union[list[str], list[fhirpy.lib.SyncFHIRReference], list[fhirpy.lib.SyncFHIRResource]]] = None, params: dict = {})
  gatherText(input: Optional[Union[list[str], list[fhirpy.lib.SyncFHIRReference], list[fhirpy.lib.SyncFHIRResource]]] = None, typeLookUps: Optional[list] = None, lookUps: Optional[list] = None, mapped: bool = False, includeMeta: bool = False, includeEmpty: bool = False, defaultLookUps: bool = True, includeDuplicates: bool = False)

    extract Text from resources by lookups.

    Parameters:

      - input – Data to extract text from.

      - resourceType – The type is used the include type specific lookups.

      - lookUps (list, optional) – List of lookups to include in the text extraction.

      - mapped (bool, optional) – Store text labels as dictionary keys.

      - includeMeta (bool, optional) – Include the resource meta data.

      - includeEmpty (bool, optional) – Include empty Text for labels.

      - defaultLookUps (bool, optional) – Include the list of default Lookups.

      - includeDuplicates (bool, optional) – Include duplicated Test string.

  gatherValuesForKeys(keys: list[str], params: Optional[dict] = None, input: Optional[Union[list[str], list[fhirpy.lib.SyncFHIRReference], list[fhirpy.lib.SyncFHIRResource]]] = None)
  validate(references: Optional[Union[list[str], list[fhirpy.lib.SyncFHIRReference], list[fhirpy.lib.SyncFHIRResource]]] = None)

## fhirpack.transformation.base_test module

## fhirpack.transformation.condition module

class fhirpack.transformation.condition.TransformerConditionMixin

  Bases: `BaseTransformerMixin`

  __doc__ = None
  __module__ = 'fhirpack.transformation.condition'
  transformerConditionMethod()

## fhirpack.transformation.observation module

class fhirpack.transformation.observation.TransformerObservationMixin

  Bases: `BaseTransformerMixin`

  __doc__ = None
  __module__ = 'fhirpack.transformation.observation'
  transformerObservationMethod()

## fhirpack.transformation.patient module

class fhirpack.transformation.patient.TransformerPatientMixin

  Bases: `BaseTransformerMixin`

  __doc__ = None
  __module__ = 'fhirpack.transformation.patient'
  transformerPatientMethod()

## Module contents

class fhirpack.transformation.TransformerMixin

  Bases: `TransformerObservationMixin`, `TransformerPatientMixin`, `TransformerConditionMixin`

  __doc__ = None
  __module__ = 'fhirpack.transformation'